@@ -158,7 +158,36 @@ try {
                     if (!$site) {
                         throw new Exception('Site selection required');
                     }
-                    $result = $engine->createSiteBackup($backupUser, $site, $targetId);
+                    
+                    if ($site === '*') {
+                        // Backup all sites
+                        $sites = $engine->getUserSites($backupUser);
+                        if (empty($sites)) {
+                            throw new Exception('No sites found for user');
+                        }
+                        
+                        $results = [];
+                        foreach ($sites as $singleSite) {
+                            try {
+                                $results[] = $engine->createSiteBackup($backupUser, $singleSite, $targetId);
+                            } catch (Exception $e) {
+                                // Log error but continue with other sites
+                                error_log("Failed to backup site $singleSite: " . $e->getMessage());
+                            }
+                        }
+                        
+                        if (empty($results)) {
+                            throw new Exception('Failed to backup any sites');
+                        }
+                        
+                        $result = [
+                            'success' => true,
+                            'backup_id' => $results[0]['backup_id'], // Return first backup ID
+                            'message' => 'Created ' . count($results) . ' site backups'
+                        ];
+                    } else {
+                        $result = $engine->createSiteBackup($backupUser, $site, $targetId);
+                    }
                     break;
                     
                 case 'userfiles':
@@ -170,7 +199,36 @@ try {
                     if (!$database) {
                         throw new Exception('Database selection required');
                     }
-                    $result = $engine->createDatabaseBackup($backupUser, $database, $targetId);
+                    
+                    if ($database === '*') {
+                        // Backup all databases
+                        $databases = $engine->getUserDatabases($backupUser);
+                        if (empty($databases)) {
+                            throw new Exception('No databases found for user');
+                        }
+                        
+                        $results = [];
+                        foreach ($databases as $singleDb) {
+                            try {
+                                $results[] = $engine->createDatabaseBackup($backupUser, $singleDb, $targetId);
+                            } catch (Exception $e) {
+                                // Log error but continue with other databases
+                                error_log("Failed to backup database $singleDb: " . $e->getMessage());
+                            }
+                        }
+                        
+                        if (empty($results)) {
+                            throw new Exception('Failed to backup any databases');
+                        }
+                        
+                        $result = [
+                            'success' => true,
+                            'backup_id' => $results[0]['backup_id'], // Return first backup ID
+                            'message' => 'Created ' . count($results) . ' database backups'
+                        ];
+                    } else {
+                        $result = $engine->createDatabaseBackup($backupUser, $database, $targetId);
+                    }
                     break;
                     
                 default:
@@ -242,6 +300,10 @@ try {
                 $filters['status'] = $_GET['status'];
             }
             
+            if (isset($_GET['search'])) {
+                $filters['search'] = $_GET['search'];
+            }
+            
             $backups = BackupHistory::listBackups(null, $filters);
             $totalCount = BackupHistory::countBackups(null, $filters);
             
